#ifndef __DBUS_PROXY_CONEXUS_DBUS_IPV4_ADDRESS_H
#define __DBUS_PROXY_CONEXUS_DBUS_IPV4_ADDRESS_H

#include <dbus-cxx.h>


namespace Conexus {
  namespace DBus {
    namespace IPv4 {

      class AddressProxy : public ::DBus::ObjectProxy
      {
        protected:
          AddressProxy( ::DBus::Connection::pointer conn, const std::string& dest="Conexus.IPv4.Address", const std::string& path="/Conexus/IPv4/Address"):
            ::DBus::ObjectProxy(conn, dest, path)
          {
            ::DBus::Path child_path;

            m_method_address_u = this->create_method<uint32_t>( "Conexus.IPv4.Address", "address" );
            m_method_address_string_s = this->create_method<std::string>( "Conexus.IPv4.Address", "address_string" );
            m_method_subnet_mask_u = this->create_method<uint32_t>( "Conexus.IPv4.Address", "subnet_mask" );
            m_method_subnet_mask_string_s = this->create_method<std::string>( "Conexus.IPv4.Address", "subnet_mask_string" );
            m_method_prefix_length_u = this->create_method<uint32_t>( "Conexus.IPv4.Address", "prefix_length" );
            m_method_prefix_length_string_s = this->create_method<std::string>( "Conexus.IPv4.Address", "prefix_length_string" );
            m_method_address_subnet_mask_string_s = this->create_method<std::string>( "Conexus.IPv4.Address", "address_subnet_mask_string" );
            m_method_cidr_address_string_s = this->create_method<std::string>( "Conexus.IPv4.Address", "cidr_address_string" );
            m_method_prefix_u = this->create_method<uint32_t>( "Conexus.IPv4.Address", "prefix" );
            m_method_prefix_string_s = this->create_method<std::string>( "Conexus.IPv4.Address", "prefix_string" );
            m_method_broadcast_address_u = this->create_method<uint32_t>( "Conexus.IPv4.Address", "broadcast_address" );
            m_method_broadcast_address_string_s = this->create_method<std::string>( "Conexus.IPv4.Address", "broadcast_address_string" );
            m_method_local_address_u = this->create_method<uint32_t>( "Conexus.IPv4.Address", "local_address" );
            m_method_local_address_string_s = this->create_method<std::string>( "Conexus.IPv4.Address", "local_address_string" );
            m_method_port_q = this->create_method<uint16_t>( "Conexus.IPv4.Address", "port" );
            m_method_port_string_s = this->create_method<std::string>( "Conexus.IPv4.Address", "port_string" );
            m_method_set_address_vu = this->create_method<void,uint32_t>( "Conexus.IPv4.Address", "set_address" );
            m_method_set_address_vs = this->create_method<void,std::string>( "Conexus.IPv4.Address", "set_address" );
            m_method_set_address_vsq = this->create_method<void,std::string,uint16_t>( "Conexus.IPv4.Address", "set_address" );
            m_method_set_address_subnet_mask_vuu = this->create_method<void,uint32_t,uint32_t>( "Conexus.IPv4.Address", "set_address_subnet_mask" );
            m_method_set_address_prefix_length_vuu = this->create_method<void,uint32_t,uint32_t>( "Conexus.IPv4.Address", "set_address_prefix_length" );
            m_method_set_subnet_mask_vu = this->create_method<void,uint32_t>( "Conexus.IPv4.Address", "set_subnet_mask" );
            m_method_set_subnet_mask_vs = this->create_method<void,std::string>( "Conexus.IPv4.Address", "set_subnet_mask" );
            m_method_set_prefix_length_vu = this->create_method<void,uint32_t>( "Conexus.IPv4.Address", "set_prefix_length" );
            m_method_set_prefix_length_vs = this->create_method<void,std::string>( "Conexus.IPv4.Address", "set_prefix_length" );
            m_method_set_port_vq = this->create_method<void,uint16_t>( "Conexus.IPv4.Address", "set_port" );
            m_method_set_port_vs = this->create_method<void,std::string>( "Conexus.IPv4.Address", "set_port" );
            m_method_is_valid_hostname_bs = this->create_method<bool,std::string>( "Conexus.IPv4.Address", "is_valid_hostname" );
            m_method_hostname_s = this->create_method<std::string>( "Conexus.IPv4.Address", "hostname" );
            m_method_servicename_s = this->create_method<std::string>( "Conexus.IPv4.Address", "servicename" );
            m_method_is_private_b = this->create_method<bool>( "Conexus.IPv4.Address", "is_private" );
            m_method_is_reserved_b = this->create_method<bool>( "Conexus.IPv4.Address", "is_reserved" );
            m_method_is_loopback_b = this->create_method<bool>( "Conexus.IPv4.Address", "is_loopback" );
            m_method_is_broadcast_b = this->create_method<bool>( "Conexus.IPv4.Address", "is_broadcast" );
            m_method_is_multicast_b = this->create_method<bool>( "Conexus.IPv4.Address", "is_multicast" );
            m_method_is_any_b = this->create_method<bool>( "Conexus.IPv4.Address", "is_any" );
            m_method_is_ipv4_b = this->create_method<bool>( "Conexus.IPv4.Address", "is_ipv4" );
            m_method_is_ipv6_b = this->create_method<bool>( "Conexus.IPv4.Address", "is_ipv6" );
            m_signal_changed = this->create_signal<void>( "Conexus.IPv4.Address", "changed" );
            m_signal_address_changed = this->create_signal<void>( "Conexus.IPv4.Address", "address_changed" );
            m_signal_port_changed = this->create_signal<void>( "Conexus.IPv4.Address", "port_changed" );
            m_signal_prefix_changed = this->create_signal<void>( "Conexus.IPv4.Address", "prefix_changed" );
          }

        public:

          typedef DBusCxxPointer<AddressProxy> pointer;

          static pointer create( ::DBus::Connection::pointer conn,
                                 const std::string& dest="Conexus.IPv4.Address",
                                 const std::string& path="/Conexus/IPv4/Address"
                               )
          { return pointer( new AddressProxy(conn, dest, path)); }


          uint32_t address( ) { return (*m_method_address_u)(); }

          std::string address_string( ) { return (*m_method_address_string_s)(); }

          uint32_t subnet_mask( ) { return (*m_method_subnet_mask_u)(); }

          std::string subnet_mask_string( ) { return (*m_method_subnet_mask_string_s)(); }

          uint32_t prefix_length( ) { return (*m_method_prefix_length_u)(); }

          std::string prefix_length_string( ) { return (*m_method_prefix_length_string_s)(); }

          std::string address_subnet_mask_string( ) { return (*m_method_address_subnet_mask_string_s)(); }

          std::string cidr_address_string( ) { return (*m_method_cidr_address_string_s)(); }

          uint32_t prefix( ) { return (*m_method_prefix_u)(); }

          std::string prefix_string( ) { return (*m_method_prefix_string_s)(); }

          uint32_t broadcast_address( ) { return (*m_method_broadcast_address_u)(); }

          std::string broadcast_address_string( ) { return (*m_method_broadcast_address_string_s)(); }

          uint32_t local_address( ) { return (*m_method_local_address_u)(); }

          std::string local_address_string( ) { return (*m_method_local_address_string_s)(); }

          uint16_t port( ) { return (*m_method_port_q)(); }

          std::string port_string( ) { return (*m_method_port_string_s)(); }

          void set_address( uint32_t address ) { return (*m_method_set_address_vu)( address); }

          void set_address( std::string address ) { return (*m_method_set_address_vs)( address); }

          void set_address( std::string address, uint16_t port ) { return (*m_method_set_address_vsq)( address, port); }

          void set_address_subnet_mask( uint32_t address, uint32_t subnet_mask ) { return (*m_method_set_address_subnet_mask_vuu)( address, subnet_mask); }

          void set_address_prefix_length( uint32_t address, uint32_t prefix_length ) { return (*m_method_set_address_prefix_length_vuu)( address, prefix_length); }

          void set_subnet_mask( uint32_t subnet_mask ) { return (*m_method_set_subnet_mask_vu)( subnet_mask); }

          void set_subnet_mask( std::string subnet_mask ) { return (*m_method_set_subnet_mask_vs)( subnet_mask); }

          void set_prefix_length( uint32_t prefix_length ) { return (*m_method_set_prefix_length_vu)( prefix_length); }

          void set_prefix_length( std::string prefix_length ) { return (*m_method_set_prefix_length_vs)( prefix_length); }

          void set_port( uint16_t port ) { return (*m_method_set_port_vq)( port); }

          void set_port( std::string port ) { return (*m_method_set_port_vs)( port); }

          bool is_valid_hostname( std::string name ) { return (*m_method_is_valid_hostname_bs)( name); }

          std::string hostname( ) { return (*m_method_hostname_s)(); }

          std::string servicename( ) { return (*m_method_servicename_s)(); }

          bool is_private( ) { return (*m_method_is_private_b)(); }

          bool is_reserved( ) { return (*m_method_is_reserved_b)(); }

          bool is_loopback( ) { return (*m_method_is_loopback_b)(); }

          bool is_broadcast( ) { return (*m_method_is_broadcast_b)(); }

          bool is_multicast( ) { return (*m_method_is_multicast_b)(); }

          bool is_any( ) { return (*m_method_is_any_b)(); }

          bool is_ipv4( ) { return (*m_method_is_ipv4_b)(); }

          bool is_ipv6( ) { return (*m_method_is_ipv6_b)(); }

          ::DBus::signal_proxy<void >& signal_changed() { return *m_signal_changed; }

          ::DBus::signal_proxy<void >& signal_address_changed() { return *m_signal_address_changed; }

          ::DBus::signal_proxy<void >& signal_port_changed() { return *m_signal_port_changed; }

          ::DBus::signal_proxy<void >& signal_prefix_changed() { return *m_signal_prefix_changed; }


        protected:


          ::DBus::MethodProxy<uint32_t>::pointer m_method_address_u;
          ::DBus::MethodProxy<std::string>::pointer m_method_address_string_s;
          ::DBus::MethodProxy<uint32_t>::pointer m_method_subnet_mask_u;
          ::DBus::MethodProxy<std::string>::pointer m_method_subnet_mask_string_s;
          ::DBus::MethodProxy<uint32_t>::pointer m_method_prefix_length_u;
          ::DBus::MethodProxy<std::string>::pointer m_method_prefix_length_string_s;
          ::DBus::MethodProxy<std::string>::pointer m_method_address_subnet_mask_string_s;
          ::DBus::MethodProxy<std::string>::pointer m_method_cidr_address_string_s;
          ::DBus::MethodProxy<uint32_t>::pointer m_method_prefix_u;
          ::DBus::MethodProxy<std::string>::pointer m_method_prefix_string_s;
          ::DBus::MethodProxy<uint32_t>::pointer m_method_broadcast_address_u;
          ::DBus::MethodProxy<std::string>::pointer m_method_broadcast_address_string_s;
          ::DBus::MethodProxy<uint32_t>::pointer m_method_local_address_u;
          ::DBus::MethodProxy<std::string>::pointer m_method_local_address_string_s;
          ::DBus::MethodProxy<uint16_t>::pointer m_method_port_q;
          ::DBus::MethodProxy<std::string>::pointer m_method_port_string_s;
          ::DBus::MethodProxy<void,uint32_t>::pointer m_method_set_address_vu;
          ::DBus::MethodProxy<void,std::string>::pointer m_method_set_address_vs;
          ::DBus::MethodProxy<void,std::string,uint16_t>::pointer m_method_set_address_vsq;
          ::DBus::MethodProxy<void,uint32_t,uint32_t>::pointer m_method_set_address_subnet_mask_vuu;
          ::DBus::MethodProxy<void,uint32_t,uint32_t>::pointer m_method_set_address_prefix_length_vuu;
          ::DBus::MethodProxy<void,uint32_t>::pointer m_method_set_subnet_mask_vu;
          ::DBus::MethodProxy<void,std::string>::pointer m_method_set_subnet_mask_vs;
          ::DBus::MethodProxy<void,uint32_t>::pointer m_method_set_prefix_length_vu;
          ::DBus::MethodProxy<void,std::string>::pointer m_method_set_prefix_length_vs;
          ::DBus::MethodProxy<void,uint16_t>::pointer m_method_set_port_vq;
          ::DBus::MethodProxy<void,std::string>::pointer m_method_set_port_vs;
          ::DBus::MethodProxy<bool,std::string>::pointer m_method_is_valid_hostname_bs;
          ::DBus::MethodProxy<std::string>::pointer m_method_hostname_s;
          ::DBus::MethodProxy<std::string>::pointer m_method_servicename_s;
          ::DBus::MethodProxy<bool>::pointer m_method_is_private_b;
          ::DBus::MethodProxy<bool>::pointer m_method_is_reserved_b;
          ::DBus::MethodProxy<bool>::pointer m_method_is_loopback_b;
          ::DBus::MethodProxy<bool>::pointer m_method_is_broadcast_b;
          ::DBus::MethodProxy<bool>::pointer m_method_is_multicast_b;
          ::DBus::MethodProxy<bool>::pointer m_method_is_any_b;
          ::DBus::MethodProxy<bool>::pointer m_method_is_ipv4_b;
          ::DBus::MethodProxy<bool>::pointer m_method_is_ipv6_b;
          ::DBus::signal_proxy<void>::pointer m_signal_changed;
          ::DBus::signal_proxy<void>::pointer m_signal_address_changed;
          ::DBus::signal_proxy<void>::pointer m_signal_port_changed;
          ::DBus::signal_proxy<void>::pointer m_signal_prefix_changed;


      };

    }
  }
}

#endif
